@@ -3,7 +3,7 @@ from django.views import View
 
 from findmydevice.json_utils import parse_json
 from findmydevice.models import Location
-from findmydevice.models.device_user import get_device_user_by_token
+from findmydevice.models.device import get_device_by_token
 
 
 class LocationView(View):
@@ -21,9 +21,9 @@ class LocationView(View):
         provider = location_data['provider']
 
         access_token = location_data['IDT']
-        device_user = get_device_user_by_token(token=access_token)
+        device = get_device_by_token(token=access_token)
         Location.objects.create(
-            device_user=device_user,
+            device=device,
             bat=bat,
             raw_date=raw_date,
             lat=lat,
@@ -36,14 +36,13 @@ class LocationView(View):
         return JsonResponse(response_data)
 
     def put(self, request):
-        print(self, 'put')
         location_data = parse_json(request)
         access_token = location_data['IDT']
-        index = int(put_data['Data'])  # noqa TODO: Use this index!
+        # index = int(location_data['Data'])  # TODO: Use this index!
 
-        device_user = get_device_user_by_token(token=access_token)
+        device = get_device_by_token(token=access_token)
 
-        queryset = Location.objects.filter(device_user=device_user).order_by('create_dt')
+        queryset = Location.objects.filter(device=device).order_by('create_dt')
         # TODO: slice via index!
 
         location = queryset.latest()
