@@ -3,7 +3,7 @@ from django.views import View
 
 from findmydevice.json_utils import parse_json
 from findmydevice.models import Location
-from findmydevice.models.device_user import get_device_user_by_token
+from findmydevice.models.device import get_device_by_token
 
 
 class LocationDataSizeView(View):
@@ -16,10 +16,10 @@ class LocationDataSizeView(View):
         put_data = parse_json(request)
         print(self, 'put', put_data)
         access_token = put_data['IDT']
-        index = int(put_data['Data'])  # noqa TODO: Use this index!
+        # index = int(put_data['Data'])  # TODO: Use this index!
 
-        device_user = get_device_user_by_token(token=access_token)
-        location_count = Location.objects.filter(device_user=device_user).count()
+        device = get_device_by_token(token=access_token)
+        location_count = Location.objects.filter(device=device).count()
         response_data = {
             'DataLength': location_count,  # newestLocationDataIndex
             'DataBeginningIndex': 0,  # smallestLocationDataIndex
